@@ -182,14 +182,14 @@ class MessageBody:
 
                 if uuid in config_data.fieldmap:
                     try:
-                        #_LOGGER.debug("UUID in field map")
+                        _LOGGER.debug("UUID in field map")
                         mapentry = config_data.fieldmap[uuid]
 
                         device = mapentry["device"]
                         stateName = mapentry["stateName"]
 
                         if device.device_type == "ClimateController":
-                            #_LOGGER.debug("ClimateController {0} {1} device_type: {2} state_name: {3} text: {4}".format(device.id, device.name, device.device_type, mapentry["stateName"], text))
+                            _LOGGER.debug("ClimateController {0} {1} device_type: {2} state_name: {3} text: {4}".format(device.id, device.name, device.device_type, mapentry["stateName"], text))
 
                             if stateName == "controls":
                                 controls = json.loads(text)
@@ -197,7 +197,7 @@ class MessageBody:
                                     con_uuid = con['uuid']
                                     con_demand = con['demand']
 
-                                    #_LOGGER.debug("  climate control - uuid: {0} demand: {1}".format(con_uuid, con_demand))
+                                    _LOGGER.debug("  climate control - uuid: {0} demand: {1}".format(con_uuid, con_demand))
 
                                     for rck,rcv in config_data.roomcontrollers.items():
                                         #_LOGGER.debug("     available controller: {0}".format(rck))
